Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS DataSync.

Actions, resources, and condition keys for AWS DataSync - Service Authorization Reference

# Actions, resources, and condition keys for AWS DataSync

AWS DataSync (service prefix: `datasync` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS DataSync
- Resource types defined by AWS DataSync
- Condition keys for AWS DataSync

## Actions defined by AWS DataSync

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddStorageSystem | Grants permission to create a storage system | Write | agent* |  |
| aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
CancelTaskExecution | Grants permission to cancel execution of a sync task | Write | taskexecution* |  |
| aws:ResourceTag/${TagKey} |
CreateAgent | Grants permission to activate an agent that you have deployed on your host | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationEfs | Grants permission to create an endpoint for an Amazon EFS file system | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationFsxLustre | Grants permission to create an endpoint for an Amazon Fsx Lustre | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationFsxOntap | Grants permission to create an endpoint for Amazon FSx for ONTAP | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationFsxOpenZfs | Grants permission to create an endpoint for Amazon FSx for OpenZFS | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationFsxWindows | Grants permission to create an endpoint for an Amazon FSx Windows File Server file system | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationHdfs | Grants permission to create an endpoint for an Amazon Hdfs | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationNfs | Grants permission to create an endpoint for a NFS file system | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationObjectStorage | Grants permission to create an endpoint for a self-managed object storage bucket | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationS3 | Grants permission to create an endpoint for an Amazon S3 bucket | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationSmb | Grants permission to create an endpoint for an SMB file system | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTask | Grants permission to create a sync task | Write | location* |  |
agent |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAgent | Grants permission to delete an agent | Write | agent* |  |
DeleteLocation | Grants permission to delete a location used by AWS DataSync | Write | location* |  |
DeleteTask | Grants permission to delete a sync task | Write | task* |  |
DescribeAgent | Grants permission to view metadata such as name, network interfaces, and the status (that is, whether the agent is running or not) about a sync agent | Read | agent* |  |
DescribeDiscoveryJob | Grants permission to describe metadata about a discovery job | Read | discoveryjob* |  |
DescribeLocationEfs | Grants permission to view metadata, such as the path information about an Amazon EFS sync location | Read | location* |  |
DescribeLocationFsxLustre | Grants permission to view metadata, such as the path information about an Amazon FSx Lustre sync location | Read | location* |  |
DescribeLocationFsxOntap | Grants permission to view metadata, such as the path information about an Amazon FSx for ONTAP sync location | Read | location* |  |
DescribeLocationFsxOpenZfs | Grants permission to view metadata, such as the path information about an Amazon FSx OpenZFS sync location | Read | location* |  |
DescribeLocationFsxWindows | Grants permission to view metadata, such as the path information about an Amazon FSx Windows sync location | Read | location* |  |
DescribeLocationHdfs | Grants permission to view metadata, such as the path information about an Amazon HDFS sync location | Read | location* |  |
DescribeLocationNfs | Grants permission to view metadata, such as the path information, about a NFS sync location | Read | location* |  |
DescribeLocationObjectStorage | Grants permission to view metadata about a self-managed object storage server location | Read | location* |  |
DescribeLocationS3 | Grants permission to view metadata, such as bucket name, about an Amazon S3 bucket sync location | Read | location* |  |
DescribeLocationSmb | Grants permission to view metadata, such as the path information, about an SMB sync location | Read | location* |  |
DescribeStorageSystem | Grants permission to view metadata about a storage system | Read | storagesystem* |  |
DescribeStorageSystemResourceMetrics | Grants permission to describe resource metrics collected by a discovery job | List | discoveryjob* |  |
DescribeStorageSystemResources | Grants permission to describe resources identified by a discovery job | List | discoveryjob* |  |
DescribeTask | Grants permission to view metadata about a sync task | Read | task* |  |
DescribeTaskExecution | Grants permission to view metadata about a sync task that is being executed | Read | taskexecution* |  |
| aws:ResourceTag/${TagKey} |
GenerateRecommendations | Grants permission to generate recommendations for a resource identified by a discovery job | Write | discoveryjob* |  |
ListAgents | Grants permission to list agents owned by an AWS account in a region specified in the request | List |  |  |
ListDiscoveryJobs | Grants permission to list discovery jobs | List |  |  |
ListLocations | Grants permission to list source and destination sync locations | List |  |  |
ListStorageSystems | Grants permission to list storage systems | List |  |  |
ListTagsForResource | Grants permission to list tags that have been added to the specified resource | Read | agent |  |
discoveryjob |  |
location |  |
storagesystem |  |
task |  |
taskexecution |  |
ListTaskExecutions | Grants permission to list executed sync tasks | List | task* |  |
| aws:ResourceTag/${TagKey} |
ListTasks | Grants permission to list of all the sync tasks | List |  |  |
RemoveStorageSystem | Grants permission to delete a storage system | Write | storagesystem* |  |
StartDiscoveryJob | Grants permission to start a discovery job for a storage system | Write | storagesystem* |  |
StartTaskExecution | Grants permission to start a specific invocation of a sync task | Write | task* |  |
| aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys |
StopDiscoveryJob | Grants permission to stop a discovery job | Write | discoveryjob* |  |
TagResource | Grants permission to apply a key-value pair to an AWS resource | Tagging | agent |  |
discoveryjob |  |
location |  |
storagesystem |  |
task |  |
taskexecution |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tags from the specified resource | Tagging | agent |  |
discoveryjob |  |
location |  |
storagesystem |  |
task |  |
taskexecution |  |
| aws:TagKeys |
UpdateAgent | Grants permission to update the name of an agent | Write | agent* |  |
UpdateDiscoveryJob | Grants permission to update a discovery job | Write | discoveryjob* |  |
UpdateLocationHdfs | Grants permission to update an HDFS sync Location | Write | location* |  |
UpdateLocationNfs | Grants permission to update an NFS sync Location | Write | location* |  |
UpdateLocationObjectStorage | Grants permission to update a self-managed object storage server location | Write | location* |  |
UpdateLocationSmb | Grants permission to update a SMB sync location | Write | location* |  |
UpdateStorageSystem | Grants permission to update a storage system | Write | storagesystem* |  |
UpdateTask | Grants permission to update metadata associated with a sync task | Write | task* |  |
UpdateTaskExecution | Grants permission to update execution of a sync task | Write | taskexecution* |  |
| aws:ResourceTag/${TagKey} |

## Resource types defined by AWS DataSync

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
agent | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:agent/$ { AgentId}` | aws:ResourceTag/${TagKey}
location | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:location/$ { LocationId}` | aws:ResourceTag/${TagKey}
task | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:task/$ { TaskId}` | aws:ResourceTag/${TagKey}
taskexecution | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:task/$ { TaskId}/execution/$ { ExecutionId}` | aws:ResourceTag/${TagKey}
storagesystem | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:system/$ { StorageSystemId}` | aws:ResourceTag/${TagKey}
discoveryjob | `arn:$ { Partition}:datasync:$ { Region}:$ { AccountId}:system/$ { StorageSystemId}/job/$ { DiscoveryJobId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS DataSync

AWS DataSync defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tag key-value pairs associated with the resource | String
aws:TagKeys | Filters access by the tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.